SystemOrganization addCategory: #'Grease-Squeak-Core'!

GRPharoPlatform subclass: #GRSqueakPlatform
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Grease-Squeak-Core'!

!GRSqueakPlatform class methodsFor: 'class initialization' stamp: 'JohnMcKeon 3/19/2015 22:16'!
initialize
	super initialize.
	self select! !

!GRSqueakPlatform methodsFor: 'file library' stamp: 'pmm 7/15/2015 15:07'!
defaultDirectoryPathString
	^ FileDirectory default fullName! !

!GRSqueakPlatform methodsFor: 'file library' stamp: 'JohnMcKeon 12/26/2014 19:35'!
deleteFile: aFileName inFolder: aPathString 
	(FileDirectory on: aPathString)
		deleteFileNamed: aFileName! !

!GRSqueakPlatform methodsFor: 'file library' stamp: 'JohnMcKeon 12/31/2014 09:23'!
directoriesIn: aPathString
	"Return a collection of absolute paths for all the files (no directories) in the directory given by aPathString
	must not include file names that start with ."
	| directory |
	directory := FileDirectory default directoryNamed: aPathString.
	^ (directory directoryNames
		reject: [ :each | each first = $. ])
		collect: [ :each | directory fullNameFor: each ]! !

!GRSqueakPlatform methodsFor: 'private' stamp: 'JohnMcKeon 12/26/2014 19:36'!
doSilently: aBlock
	^SystemChangeNotifier uniqueInstance doSilently: aBlock! !

!GRSqueakPlatform methodsFor: 'file library' stamp: 'JohnMcKeon 12/31/2014 09:32'!
ensureExistenceOfFolder: aString
	^FileDirectory default assureExistenceOfPath: aString! !

!GRSqueakPlatform methodsFor: 'file library' stamp: 'JohnMcKeon 12/31/2014 09:35'!
fileExists: aString
	^FileDirectory default fileExists: aString! !

!GRSqueakPlatform methodsFor: 'file library' stamp: 'pmm 7/15/2015 16:48'!
fileNameFor: aPathString
	| path |
	path := FileDirectory default fullPathFor: aPathString.
	^ (path size > 1 and: [ path endsWith: FileDirectory slash ])
		ifTrue: [ path allButLast: FileDirectory slash size ]
		ifFalse: [ path ]! !

!GRSqueakPlatform methodsFor: 'file library' stamp: 'pmm 7/15/2015 14:47'!
fileStreamOn: aString do: aBlock binary: aBoolean
	^ aBoolean
		ifTrue: [
			FileStream fileNamed: aString do: [ :stream |
				stream binary.
				aBlock value: stream ] ]
		ifFalse: [
			MultiByteFileStream fileNamed: aString do: [ :stream |
				stream
					ascii;
					wantsLineEndConversion: true.
					aBlock value: stream ] ]! !

!GRSqueakPlatform methodsFor: 'file library' stamp: 'JohnMcKeon 12/26/2014 19:35'!
filesIn: aPathString
	"Return a collection of absolute paths for all the files (no directories) in the directory given by aPathString
	must not include file names that start with ."
	| directory |
	directory := FileDirectory default directoryNamed: aPathString.
	^ (directory fileNames
		reject: [ :each | each first = $. ])
		collect: [ :each | directory fullNameFor: each ]! !

!GRSqueakPlatform methodsFor: 'file library' stamp: 'pmm 7/15/2015 15:21'!
isDirectory: aPathString
	^ (FileDirectory forFileName: aPathString) directoryEntry isDirectory! !

!GRSqueakPlatform methodsFor: 'file library' stamp: 'JohnMcKeon 12/27/2014 11:04'!
localNameOf: aFilename
	^FileDirectory localNameFor: aFilename! !

!GRSqueakPlatform methodsFor: 'file library' stamp: 'JohnMcKeon 12/26/2014 19:35'!
pathSeparator
	^ FileDirectory pathNameDelimiter asString! !

!GRSqueakPlatform methodsFor: 'file library' stamp: 'JohnMcKeon 12/26/2014 19:36'!
write: aStringOrByteArray toFile: aFileNameString inFolder: aFolderString
	"writes aStringOrByteArray to a file named aFilenameString in the folder aFolderString"
	| folder stream fullFilePath |
	folder := FileDirectory default directoryNamed: aFolderString.
	fullFilePath := folder fullNameFor: aFileNameString.
	stream := aStringOrByteArray isString
		ifTrue: [		
			(MultiByteFileStream forceNewFileNamed: fullFilePath)
				ascii;
				wantsLineEndConversion: true;
				yourself ]
		ifFalse: [ (FileStream forceNewFileNamed: fullFilePath) binary ].
	[ stream nextPutAll: aStringOrByteArray ]
		ensure: [ stream close ]! !

!SmallInteger methodsFor: '*grease-squeak-core' stamp: 'pmm 7/15/2015 16:31'!
sizeInMemory
    "SmallInteger occupy 0 bytes since the only space occupied by a SmallInteger is the space of the slot containing it.  There is no SmallInteger object beyond the slot. From another POV, it could be 4, the size of the slot. But we don't count the size of the slots, they are already counted in the containing object, that's why it should answer 0."
   ^0.! !

!Object methodsFor: '*grease-squeak-core' stamp: 'cmm 10/7/2015 10:22'!
sizeInMemory
    "Answer the number of bytes consumed by this instance including object header."
    | contentBytes |

	contentBytes := Smalltalk wordSize. "base header"
	contentBytes := contentBytes + (self class instSize * Smalltalk wordSize). "instance vars"

	self class isVariable ifTrue:[ | bytesPerElement | "indexed elements"
		bytesPerElement := self class isBytes ifTrue: [1] ifFalse: [4].
		contentBytes := (contentBytes + (self basicSize * bytesPerElement)).
		"If we are not filling an ammount of bytes multiple of the wordSize, we do it"
		(contentBytes \\ Smalltalk wordSize) = 0 ifFalse: [
			| extraBytesToFillAWord |
			extraBytesToFillAWord := Smalltalk wordSize - (contentBytes \\ Smalltalk wordSize).
			contentBytes := contentBytes + extraBytesToFillAWord.
		]
	].

	contentBytes > 255 ifTrue:	[ contentBytes := contentBytes +  (2 * Smalltalk wordSize) ]
						ifFalse:	[ contentBytes := contentBytes + Smalltalk wordSize
								].
	^contentBytes! !
GRSqueakPlatform initialize!
